
# Note from ID Oct 22, 2015. This is a revised version of Will Pitchers script to make publication quality versions of some of the figures.

#' New & reworked figures Monday, 27 April 2015
#' ===
#'
#' Figure 1.
#' ---
#'
#' This figure uses the data from `BothLabs_Wings_28Oct.csv`.

# + read_in_wing_data
source('~/Dropbox/Dworkin_lab/DworkinLabSharedMaterial/scripts/WRP_FUNCTIONS.R', chdir = TRUE) 
source('~/Dropbox/Dworkin_lab/DworkinLabSharedMaterial/scripts/WINGPLOTSOURCE.R', chdir = TRUE) 

#wings <- read.csv( "/Volumes/Old_HD/DocStore/=WORK=/DGRP/DGRP_Phenotype_Data/BothLabs_Wings_28Oct.csv", nrow=system( "wc -l /Volumes/Old_HD/DocStore/=WORK=/DGRP/DGRP_Phenotype_Data/BothLabs_Wings_28Oct.csv" ), header=T )

wings <- read.csv( "~/Dropbox/Dworkin_lab/DworkinLabSharedMaterial/DGRP_SD/data/BothLabs_Wings_28Oct.csv", 
    nrow=system( "wc -l ~/Dropbox/Dworkin_lab/DworkinLabSharedMaterial/DGRP_SD/data/BothLabs_Wings_28Oct.csv" ), header=T )

wings$CS <- wings$Csize * wings$Scale

dim( wings[ wings$Lab=="Dwo", ] )
dim( wings[ wings$Lab=="Hou", ] )

#' Panel A is now a wing-blur plot of within lab line means. In the first version I just used the same colour for all the line means. (here I'm using the within-sex, within-lab, line means)
#' The second version I used a translucent blue for Dworkin-lab line means and red for Houle-lab line means...
#' Th

# + panel_A
# calculate line means
wingmeans <- aggregate( wings[, 10:107], by=c( wings["Line"], wings["Lab"], wings["Sex"] ), mean )

# calculate VC & effect size for later
Dwing_means <- by( wings[ wings$Lab =="Dwo", 10:105], wings$LineNum[ wings$Lab =="Dwo"], colMeans )
Hwing_means <- by( wings[ wings$Lab =="Hou", 10:105], wings$LineNum[ wings$Lab =="Hou"], colMeans )

Dwing_mean_shape <- colMeans( wings[ wings$Lab =="Dwo", 10:105] )
Hwing_mean_shape <- colMeans( wings[ wings$Lab =="Hou", 10:105] )

both_labs_lines <- intersect( names(Dwing_means), names(Hwing_means) )
btwn_labs_vc <- rep( NA, length( both_labs_lines ))
btwn_labs_pd.dwo <- rep( NA, length( both_labs_lines ))
btwn_labs_pd.hou <- rep( NA, length( both_labs_lines ))

for(i in 1:length( both_labs_lines )) {
  Dwing_diff <- Dwing_mean_shape - Dwing_means[both_labs_lines[i]][[1]]
  Hwing_diff <- Hwing_mean_shape - Hwing_means[both_labs_lines[i]][[1]]
  btwn_labs_vc[i] <- ang.vec.abs( Dwing_diff, Hwing_diff )[1]
  btwn_labs_pd.dwo[i] <- PD( Dwing_diff )
  btwn_labs_pd.hou[i] <- PD( Hwing_diff )
}

# now the plot itself
par( mar=c( 1,1,1,1 ) )

WingBlur( wingmeans[, 4:99], wingcex=0 )

WingBlur( wingmeans[, 4:99], wingcex=0, wingcol=c("#ad000032", "#add8e632")[ wingmeans$Lab ] )

### trying for a density fade...
grandmeanshape <- colMeans( wingmeans[, 4:99] )
wingmeans$diff <- rowSums( abs( wingmeans[, 4:99] - grandmeanshape ))

mycols <- colorRampPalette( c("#add8e6", "#add832"), space="rgb")

MyCols <- gsub( '(#[[:alnum:]]{6})', '\\115', mycols( nrow( wingmeans )) )

wingmeans_sort <- wingmeans[ order( wingmeans$diff ) ,]

WingBlur( wingmeans[, 4:99], wingcex=0, wingcol=MyCols, meanlwd=1, meancol="black" )
###


# pdf( "~/Dropbox/IanShare/Manuscript1/FigsTables/Figure_1.pdf" )
# par( mfrow=c( 2,2 ))
# WingBlur( wingmeans[, 4:99], wingcex=0, wingcol=MyCols, meanlwd=1, meancol="black" )



# New Figure 3 (Oct 2018 - ID)
# Revised to fit the Genetics requirements

pdf( "~/Dropbox/IanShare/Manuscript1//Current_Manuscript_Submission/Figures/NewFigure_3.pdf", height = 4, width=7 )
par( mar=c(4.3, 4.3, 0.9, 1.2 ))

par(mfrow=c(1, 2))

#' Panel A is the effect size (as Procrustes distance), lab vs. lab.

# + panel_A

plot( btwn_labs_pd.hou, btwn_labs_pd.dwo, 
    xlim = c(0.009, 0.045), ylim = c(0.009, 0.045),
    xlab="Houle lab effect size", ylab="Dworkin lab effect size", 
    cex = 1.5, pch = 20, family = "sans", cex.lab= 1.2, cex.axis = 1.0, 
    xaxp = c(0.01, 0.04, 2), yaxp = c(0.01, 0.04, 2))  # number of ticks

abline( a = 0, b = 1, col = "red", lwd = 3, lty = 2 )
text( x = 0.01, y = 0.044, family = "sans", labels = c("A"), cex =  1.4)
# Panel B is the size magnitudes fo

plot( ( mean( wings$CS[ wings$Lab=="Hou" ] ) -
            by( wings$CS[ wings$Lab=="Hou" & wings$LineNum %in% both_labs_lines ],
            wings$LineNum[ wings$Lab=="Hou" & wings$LineNum %in% both_labs_lines ], mean ) ),
      ( mean( wings$CS[ wings$Lab=="Dwo" ] ) -
            by( wings$CS[ wings$Lab=="Dwo" & wings$LineNum %in% both_labs_lines ],
            wings$LineNum[ wings$Lab=="Dwo" & wings$LineNum %in% both_labs_lines ], mean ) ),
      xlim=c(-0.4, 0.6), ylim=c(-0.4, 0.6), cex = 1.5, pch=20,
      #xlab=expression(centroid size (mm)^2/n [Houle Lab]), 
      xlab=expression(paste("Houle lab wing size (", mm^2, ")")), 
      #ylab=expression(paste("Dworkin lab wing size (", mm^2, ")")), 
      ylab = "",
      #ylab="centroid size (mm)\n [Dworkin Lab]",
      family = "sans", cex.lab = 1.2, cex.axis = 1.0,
      xaxp = c(-0.4, 0.6, 2), yaxp = c(-0.4, 0.6, 2))

mtext(side = 2,  
    text = expression(paste("Dworkin lab wing size (", mm^2, ")")), 
    line = 2, cex = 1.2, family = "sans")
    
abline( a=0, b=1, col="red", lwd=3, lty=2 )
text( x = -0.37, y = 0.58, family = "sans", labels = c("B"), cex =  1.4)
dev.off()



# Supplementary Figure 1
#pdf( "~/Dropbox/IanShare/Manuscript1/FigsTables/Figure_S1_DwSize.pdf", height=8, width=8 )

par(mfrow = c(1, 2))
par(mar = c(6, 6, 1.5, 1.5) )

# Panel A - repeatability of direction of effect vs Average magnitude (shape)
plot( x = rowMeans( cbind( btwn_labs_pd.hou, btwn_labs_pd.dwo )), 
      y = btwn_labs_vc,
      ylim=c(0, 1), xlim=c(0.01, 0.045), pch=20, 
      cex = 2.9, cex.lab = 2.2, cex.axis = 1.5,
      xaxp = c(0.01, 0.04, 2), yaxp = c(0, 1, 2),
      ylab="between-lab vector correlation", xlab="mean effect size",
      family = "sans",  yaxs="i")
      
text( x = 0.01, y = 0.96, family = "sans", labels = c("A"), cex =  2.2)

# + Dworkin between-rep Csize plot
Dwings_rep <- na.omit( wings[ wings$Lab=="Dwo" & wings$Rep=="rep3" | wings$Rep=="rep4" ,] )
Dwings_rep$Rep <- factor( Dwings_rep$Rep )
Dwings_rep$Line <- factor( Dwings_rep$Line )
plotCS_rep3 <- mean( Dwings_rep$CS[ Dwings_rep$Rep=="rep3" ]) - by( Dwings_rep$CS[ Dwings_rep$Rep=="rep3" ], Dwings_rep$Line[ Dwings_rep$Rep=="rep3" ], mean )
plotCS_rep4 <- mean( Dwings_rep$CS[ Dwings_rep$Rep=="rep4" ]) - by( Dwings_rep$CS[ Dwings_rep$Rep=="rep4" ], Dwings_rep$Line[ Dwings_rep$Rep=="rep4" ], mean )

plot( plotCS_rep3, plotCS_rep4, 
    xlim=c(-0.3, 0.4), ylim=c(-0.3, 0.4),
    xlab=expression(paste("Replicate 1 wing size (", mm^2, ")")),
    ylab=expression(paste("Replicate 2 wing size (", mm^2, ")")), 
    family = "sans", cex.lab = 2.2, pch = 20, cex = 2.9, cex.axis = 1.5,
    xaxp = c(-0.3, 0.3, 2), yaxp = c(-0.3, 0.3, 2) )

abline( a=0, b=1, col="red", lwd=2, lty=2 )
text( x = -0.275, y = 0.4, family = "sans", labels = c("B"), cex =  2.2)
#dev.off()




#' New Figure 5 (October 2018). - Influence of minor allele frequency on distribution of p-values.
#' ---
#'
#' This figure uses the data from `MANOVAPvals.csv`.
#' Not the *best* possible result, but there may be something going on at MAF between 0.15 & 0.25...

# + read_in_and_parse

## Oct 2018.
## 
p_vals <- read.csv("~/Dropbox/IanShare/Manuscript1/FigsTablesDrafts/MANOVAPvals.csv" ,
                    colClasses=c( "factor", "numeric", "numeric") )

str( p_vals )

p_vals <- p_vals[ p_vals$snp != "1" & p_vals$snp != "2" & p_vals$snp != "3" & p_vals$snp != "4" , ]

expected <- c( 1:length( p_vals$WltestP ))
log_exp <- -log10(expected / (length(expected) +1) )

p_vals$log_p <- -log10( p_vals$WltestP )


# + binning by MAF...
obs_bin_1 <- p_vals[ p_vals$psnp184 < 0.02 ,]
obs_bin_2 <- p_vals[ p_vals$psnp184 > 0.02 & p_vals$psnp184 < 0.04 ,]
obs_bin_3 <- p_vals[ p_vals$psnp184 > 0.04 & p_vals$psnp184 < 0.06 ,]
obs_bin_4 <- p_vals[ p_vals$psnp184 > 0.06 & p_vals$psnp184 < 0.08 ,]
obs_bin_5 <- p_vals[ p_vals$psnp184 > 0.08 & p_vals$psnp184 < 0.01 ,]
obs_bin_6 <- p_vals[ p_vals$psnp184 > 0.10 & p_vals$psnp184 < 0.12 ,]
obs_bin_7 <- p_vals[ p_vals$psnp184 > 0.12 & p_vals$psnp184 < 0.14 ,]
obs_bin_8 <- p_vals[ p_vals$psnp184 > 0.14 & p_vals$psnp184 < 0.16 ,]
obs_bin_9 <- p_vals[ p_vals$psnp184 > 0.16 & p_vals$psnp184 < 0.18 ,]
obs_bin_10 <- p_vals[ p_vals$psnp184 > 0.18 & p_vals$psnp184 < 0.20 ,]
obs_bin_11 <- p_vals[ p_vals$psnp184 > 0.20 & p_vals$psnp184 < 0.22 ,]
obs_bin_12 <- p_vals[ p_vals$psnp184 > 0.22 & p_vals$psnp184 < 0.24 ,]
obs_bin_13 <- p_vals[ p_vals$psnp184 > 0.24 ,]

obs_bin_1$expected <- -log10( c( 1:dim( obs_bin_1 )[[1]]) / (length(c( 1:dim( obs_bin_1 )[[1]])) +1) )
obs_bin_2$expected <- -log10( c( 1:dim( obs_bin_2 )[[1]]) / (length(c( 1:dim( obs_bin_2 )[[1]])) +1) )
obs_bin_3$expected <- -log10( c( 1:dim( obs_bin_3 )[[1]]) / (length(c( 1:dim( obs_bin_3 )[[1]])) +1) )
obs_bin_4$expected <- -log10( c( 1:dim( obs_bin_4 )[[1]]) / (length(c( 1:dim( obs_bin_4 )[[1]])) +1) )
obs_bin_5$expected <- -log10( c( 1:dim( obs_bin_5 )[[1]]) / (length(c( 1:dim( obs_bin_5 )[[1]])) +1) )
obs_bin_6$expected <- -log10( c( 1:dim( obs_bin_6 )[[1]]) / (length(c( 1:dim( obs_bin_6 )[[1]])) +1) )
obs_bin_7$expected <- -log10( c( 1:dim( obs_bin_7 )[[1]]) / (length(c( 1:dim( obs_bin_7 )[[1]])) +1) )
obs_bin_8$expected <- -log10( c( 1:dim( obs_bin_8 )[[1]]) / (length(c( 1:dim( obs_bin_8 )[[1]])) +1) )
obs_bin_9$expected <- -log10( c( 1:dim( obs_bin_9 )[[1]]) / (length(c( 1:dim( obs_bin_9 )[[1]])) +1) )
obs_bin_10$expected <- -log10( c( 1:dim( obs_bin_10 )[[1]]) / (length(c( 1:dim( obs_bin_10 )[[1]])) +1) )
obs_bin_11$expected <- -log10( c( 1:dim( obs_bin_11 )[[1]]) / (length(c( 1:dim( obs_bin_11 )[[1]])) +1) )
obs_bin_12$expected <- -log10( c( 1:dim( obs_bin_12 )[[1]]) / (length(c( 1:dim( obs_bin_12 )[[1]])) +1) )
obs_bin_13$expected <- -log10( c( 1:dim( obs_bin_13 )[[1]]) / (length(c( 1:dim( obs_bin_13 )[[1]])) +1) )


mycols <- heat.colors( 13 )

#pdf( "~/Dropbox/IanShare/Manuscript1/Current_Manuscript_Submission/Figures/Figure_2_QQ.pdf",
#    height = 3.3, width = 3.3 )

par( mfrow=c( 1,1 ), mar=c( 4.3, 4.3,1 0.9, 1 ) )

# + draw the plot
plot( log_exp, p_vals$log_p, xlim=c(0, 9), ylim=c(0, 9), typ='l', xlab="log expected", ylab="log observed", cex.lab = 2.2 )
      abline( a=0, b=1, lty=2 )
      points( obs_bin_1$expected, obs_bin_1$log_p, col=mycols[1], typ='l', lwd=2 )
      points( obs_bin_2$expected, obs_bin_2$log_p, col=mycols[2], typ='l', lwd=2 )
      points( obs_bin_3$expected, obs_bin_3$log_p, col=mycols[3], typ='l', lwd=2 )
      points( obs_bin_4$expected, obs_bin_4$log_p, col=mycols[4], typ='l', lwd=2 )
      points( obs_bin_5$expected, obs_bin_5$log_p, col=mycols[5], typ='l', lwd=2 )
      points( obs_bin_6$expected, obs_bin_6$log_p, col=mycols[6], typ='l', lwd=2 )
      points( obs_bin_7$expected, obs_bin_7$log_p, col=mycols[7], typ='l', lwd=2 )
      points( obs_bin_8$expected, obs_bin_8$log_p, col=mycols[8], typ='l', lwd=2 )
      points( obs_bin_9$expected, obs_bin_9$log_p, col=mycols[9], typ='l', lwd=2 )
      points( obs_bin_10$expected, obs_bin_10$log_p, col=mycols[10], typ='l', lwd=2 )
      points( obs_bin_11$expected, obs_bin_11$log_p, col=mycols[11], typ='l', lwd=2 )
      points( obs_bin_12$expected, obs_bin_12$log_p, col=mycols[12], typ='l', lwd=2 )
      points( obs_bin_13$expected, obs_bin_13$log_p, col=mycols[13], typ='l', lwd=2 )

legend( 7, 4, legend=c( "<0.02", "0.02-0.04", "0.04-0.06", "0.06-0.08", "0.08-0.10", "0.10-0.12", "0.12-0.14", "0.14-0.16", "0.16-0.18", "0.18-0.20", "0.20-0.22", "0.22-0.24", ">0.24" ), col=mycols[1:13], lwd=2, cex=0.75 )

#dev.off()

### OR:

# + re-binning
obs_bin_lo <- p_vals[ p_vals$psnp184 < 0.15 ,]
obs_bin_hi <- p_vals[ p_vals$psnp184 > 0.15 ,]

obs_bin_lo$expected <- -log10( c( 1:dim( obs_bin_lo )[[1]]) / (length(c( 1:dim( obs_bin_lo )[[1]])) +1) )
obs_bin_hi$expected <- -log10( c( 1:dim( obs_bin_hi )[[1]]) / (length(c( 1:dim( obs_bin_hi )[[1]])) +1) )

# par( mfrow=c( 1,1 ), mar=c( 4.3,4.3,0.9,1 ), family = "sans")
# mycols <- heat.colors( 3 )

# pdf( "~/Dropbox/IanShare/Manuscript1/FigsTables/Figure_3_QQ.pdf" )
pdf( "~/Dropbox/IanShare/Manuscript1/Current_Manuscript_Submission/Figures/Figure_5_QQ.pdf",
   height = 3.3, width = 3.3 )

tiff("~/Dropbox/IanShare/Manuscript1/FigsTables/Figure_3_QQ.tiff",
    res = 300, units="in", width = 5, height = 5)

par( mfrow=c( 1,1 ), mar=c( 4.3,4.3, 0.7, 0.7 ), family = "sans")

plot( log_exp, p_vals$log_p, 
    xlim=c(0, 9), ylim=c(0, 9), typ='l', 
    xlab="log expected p-values", ylab="log observed p-values", 
    lwd = 2.5, family = "sans", 
    cex.lab = 1.15) 
    
abline( a=0, b=1, lty=2, lwd=3 )

points( obs_bin_lo$expected, obs_bin_lo$log_p, col="red", typ = 'l', lwd = 2.5 )
points( obs_bin_hi$expected, obs_bin_hi$log_p, col="blue", typ = 'l', lwd = 2.5  )

legend( x = "bottomright", 
    legend=c( "all", "<0.15", ">0.15" ), 
    col=c( "black", "red", "blue"),
    lwd = 2.5, cex = 0.75)

dev.off()



#' Figure 7
#' ---
#'
#' This figure uses the data from `MolG_stats_Apr15.csv`.
#' This is from the PC-by-PC GWAS run at MAC>=3, with the values from PC12 trimmed off at SNP 3216000000

# + molG_plots

plot_vals <- read.csv( "~/Dropbox/IanShare/Manuscript1/FigsTables/MolG_stats_Apr15.csv" )
plot_vals

# pdf( "~/Dropbox/IanShare/Manuscript1/FigsTables/Figure_7_Re-G.pdf", height=7, width=11 )

fig7lab <- paste( "PC", c(1,5,10,15,20), coll='', sep='' )

par( mfrow=c(2, 2), mar=c(4, 6, 1.2, 1) )
barplot( plot_vals$hit_count, width=1, space=0, col="red", main="", ylab="count of SNPs", cex.lab=1.5 )
axis( 1, at=0.5:19.5, labels=rep('', 20) )
axis( 1, c(0.5, 4.5, 9.5, 14.5, 19.5), fig7lab, cex.axis=1.5 )
mtext( "A", side=3, line=-0.2, at=-3, cex=1.5 )

barplot( plot_vals$hit_eff_mean, width=1, space=0, col="grey", main="", ylab="mean effect size", cex.lab=1.5 )
axis( 1, at=0.5:19.5, labels=rep('', 20) )
axis( 1, c(0.5, 4.5, 9.5, 14.5, 19.5), fig7lab, cex.axis=1.5 )
mtext( "B", side=3, line=-0.2, at=-3, cex=1.5 )

barplot( plot_vals$eff_100_mean, width=1, space=0, col="grey", main="", ylab="mean effect size \n (100 largest effects)", cex.lab=1.5 )
axis( 1, at=0.5:19.5, labels=rep('', 20) )
axis( 1, c(0.5, 4.5, 9.5, 14.5, 19.5), fig7lab, cex.axis=1.5 )
mtext( "C", side=3, line=-0.2, at=-3, cex=1.5 )

barplot( plot_vals$p_100_eff_mean, width=1, space=0, col="grey", main="", ylab="mean effect size \n (100 smallest p-vals)", cex.lab=1.5 )
axis( 1, at=0.5:19.5, labels=rep('', 20) )
axis( 1, c(0.5, 4.5, 9.5, 14.5, 19.5), fig7lab, cex.axis=1.5 )
mtext( "D", side=3, line=-0.2, at=-3, cex=1.5 )

# dev.off()


#' Figure ??
#' ---
#' add in 2-panel manhattan plot

# manova_results <- read.csv( "/Volumes//Old_HD/DocStore/=WORK=/DGRP/HQMANOVA2.csv",
#                           nrow= system( "wc -l /Volumes//Old_HD/DocStore/=WORK=/DGRP/HQMANOVA2.csv" ))
#
# str( manova_results )



#' Figure 6
#' ---
#'
#' This figure uses the data from `MolG_stats_Apr15.csv`.
#' This is from the PC-by-PC GWAS run at MAC>=3, with the values from PC12 trimmed off at SNP 3216000000

