
library(glmnet)
library(plyr)
setwd("D:/Dropbox/DH/Flywing/DGRP/GLMnet/data")

# This program is to do they SNP by SNP multiple regression in GLMnet
# We first need to read in the data files, 
# loop over SNPS,  combine data for each
# do GLMnet analysis
# save results

findminalpha=function(nf,reps,pdf,rdf){
  alphavals=seq(0,1,0.1)
  MSEmin=matrix(nrow=length(alphavals),ncol=reps)
  lambdaatmin=matrix(nrow=length(alphavals),ncol=reps)
  for (r in 1:reps) {
    folds=sample(1:nf,size=nrow(rdf),replace=TRUE)
    for (a in 1:length(alphavals)){
      #  en =glmnet(pdf,rdf,family="mgaussian",alpha=a)
      cven = cv.glmnet(pdf,rdf,family="mgaussian",foldid=folds,alpha=alphavals[a])
      MSEmin[a,r]=min(cven$cvm) 
      lambdaatmin[a,r]=cven$lambda.min
      cat("Done with alpha=",a," in rep ", r , "\n")
    }
    cat("Done with ", r , " reps\n")
    MSEres=list(alpha=alphavals,MSEmin=MSEmin,lambdamin=lambdaatmin)
  }
  return(MSEres)
}

extractSNPs <-function(resobj,alpha,slam,labl)
{
  # cat("Entering extractSNPs with alpha",alpha," lambda ",slam,"labl ",labl,"\n")
  # information about the file and parameters used.
  desc= c(deparse(substitute(resobj)),alpha,slam,labl)
  # resobj$beta[[1]]@i is a vector of the arbitrary numbers of SNPs that have an effect at each of the lambdas
  vessigsnp=resobj$beta[[1]]@i
  # Pairs each use of a SNP with its position in the whole list
  # 0 is the first predictor, and max predictor is number of predictors-1
  vecorder=cbind(vessigsnp+1,seq(1:length(vessigsnp)))
  lambdasnp = matrix(NA,100,3)
  if (resobj$df[1]==0) {
    lambdasnp[1,1]=0
    lambdasnp[1,2]=0
  }
  else {
    lambdasnp[1,1]=1
    lambdasnp[1,2]=resobj$df[1]
  }
  lambdasnp[1,3]=resobj$df[1]
  for (i in 2:100) 
  {
    lambdasnp[i,1]=lambdasnp[i-1,2]+1
    lambdasnp[i,2]=lambdasnp[i-1,2]+resobj$df[i]
    lambdasnp[i,3]=resobj$df[i]
  }
  # lambdasnp has the numbers of the first and last and total numbers of SNPs in the model at each lambda
  #sorts vecorder by SNP number
  vecorder=vecorder[order(vecorder[,1]),]
  firstsnp=vecorder[!duplicated(vecorder[,1]),2]
  rvecorder=vecorder[order(vecorder[,1],-vecorder[,2]),]
  lastsnp=rvecorder[!duplicated(rvecorder[,1]),2]
  fllambda=matrix(NA,length(firstsnp),2)
  for (j in 1:length(firstsnp)) {
    # first column is the first row of lambdasnp that firstsnp
    fllambda[j,1]=max(which(lambdasnp[,1]<=firstsnp[j]))
    fllambda[j,2]=max(which(lambdasnp[,1]<=lastsnp[j]))
  }
  # fllambda has the max and min lambda increment for each SNP in the models.
  
  snptable=count(vecorder[,1])
  startlambs= resobj$lambda[fllambda[,1]]
  lastlambs= resobj$lambda[fllambda[,2]]
  colnames(snptable)=c("signum","inmodelcount")
  snpfacts=cbind(snptable,fllambda,startlambs,lastlambs)
  colnames(snpfacts)=c("signum","inmodelcount","first","last","startlamb","lastlamb")
  # snpfacts has  all the SNPs that entered any model, how many lamnda vlaues it did, what lambda values those are
  lamb=coef(resobj,s=slam)
  varnames=names(lamb)
  namesp=lamb[[1]]@Dimnames[[1]][lamb[[1]]@i+1]
  # The estimates for the chosen lambda are in lamb[[i]]@x 
  ests = lamb[[1]]@x
  for (i in 2:59) 
  {ests = cbind(ests,lamb[[i]]@x)}
  # Calculate the 2 norm of each vector
  vectlens = sqrt(diag(ests%*% t(ests)))
  bestmodel=data.frame(cbind(lamb[[1]]@i,ests,vectlens),row.names=namesp)
  nvc=c("signum",varnames[1:59],"vlength")
  names(bestmodel)=nvc
  snpfactslamb=list(snpfacts,bestmodel,desc)
  outfile = paste(labl,"snps.csv",sep="")
  #write.csv(snpfacts,file=outfile)
  outfile = paste(labl,"mod.csv",sep="")
  #write.csv(bestmodel,file=outfile)
  names(snpfactslamb)=c("SNPdata","bestmodel","description")
  return(snpfactslamb)
} # end of extractSNPS


snpdata <- read.csv("compsnps1to2396.csv",header=TRUE,colClasses=c("snp1"="double"))
lsmean184 <- read.csv("DGRPphenotypes.csv")

# snp = subset(snpdata,focalnum==1)
# # omits all the columns with missing SNP data.
# 
# snp=snp[,colSums(is.na(snp))==0]
# snpcols=ncol(snp)
# thissnp=merge(snp,lsmean184,by="DGRP")
# pcols=c(6:snpcols,(snpcols+65):(snpcols+77))
# pdf = data.matrix(thissnp[,pcols])
# rdf = data.matrix(thissnp[,(snpcols+5):(snpcols+63)])
# #MSEmin=findminalpha(5,1,pdf,rdf)
# cvnlda = cv.glmnet(pdf,rdf,family="mgaussian",alpha=1)
# bestlamb=cvnlda$lambda[which.min(cvnlda$cvm)]
# #bestlamb=0.09
# 
# bestmodels =glmnet(pdf,rdf,family="mgaussian",alpha=1)
# devratio=bestmodels$dev.ratio[which(bestmodels$lambda==bestlamb)]
# 
# lambm=coef(bestmodels,s=bestlamb)
# names(lambm)
# # Gets the model at a particular lambda value.  alphac is just to label the results here.
# bmodm =extractSNPs(bestmodels,1,bestlamb,"sumlab")
# bmodm$bestmodel


testsnps<- function(thiscsv,first,last,alphac)
{
  # Output file
  sumlab=paste("summary",first,"to",last,"alph",alphac,sep="")
  fn = paste(sumlab,".csv",sep="") 
  fnmodel = paste(sumlab,"mod.csv",sep="") 
for (s in first:last)
{
  cat("s=",s,"\n")
  snp = subset(snpdata,focalnum==s)
  # omits all the columns with missing SNP data.
  
  snp=snp[,colSums(is.na(snp))==0]
  snpcols=ncol(snp)
  thissnp=merge(snp,lsmean184,by="DGRP")
  pcols=c(6:snpcols,(snpcols+65):(snpcols+77))
  pdf = data.matrix(thissnp[,pcols])
  rdf = data.matrix(thissnp[,(snpcols+5):(snpcols+63)])
  #MSEmin=findminalpha(5,1,pdf,rdf)
  cvnlda = cv.glmnet(pdf,rdf,family="mgaussian",alpha=alphac)
  # plot(cvnlda)
  # find the lambda value that minimizes the cross-validated error
  bestlamb=cvnlda$lambda[which.min(cvnlda$cvm)]
  #bestlamb=0.09
  
  bestmodels =glmnet(pdf,rdf,family="mgaussian",alpha=alphac)
  devratio=bestmodels$dev.ratio[which(bestmodels$lambda==bestlamb)]
  # Gets the model at a particular lambda value.  alphac is just to label the results here.
  bmod =extractSNPs(bestmodels,alphac,bestlamb,sumlab)
  #head(bmod$description)
#print(bmod$bestmodel)
#print(bmod$SNPdata[1,]) 
  nr=nrow(bmod$bestmodel) 
  rn = rownames(bmod$bestmodel)
  snpsinmodel=sum(grepl("snp",rn))
  PopSCinmodel=sum(grepl("SC",rn))
  modeldf=snpsinmodel+PopSCinmodel
  cat(bestlamb,devratio,snpsinmodel,PopSCinmodel,"\n")
  result=cbind(s,snp=snp[1,1],bmod$SNPdata[1,],bestlamb,devratio,snpsinmodel,PopSCinmodel,snpcols)
  # if (s==1) {write.csv(result, fn, row.names=FALSE,append=FALSE, na=".")}
  # else {
  #   write.csv(result, fn, row.names=FALSE,col.names=FALSE, na=".",append=TRUE)
  # }
  print(bmod$bestmodel[1:2,1:5])
  if (modeldf>0) {
  if (bmod$bestmodel[2,1]==1 ){
        mlength=mean(bmod$bestmodel[3:nr,61])
        result=cbind(result,focalln=bmod$bestmodel[2,61],mlength,bmod$bestmodel[2,2:60])
        # if (s==1) {
        #   firstres=0
        #   write.csv(result, fnmodel, row.names=FALSE,append=FALSE, na=".")
        #   }
        # else {
        #   write.csv(result, fnmodel, row.names=FALSE,col.names=FALSE, na=".",append=TRUE)
        # }
  } 
  }

#try rbind.fill(). It makes missing values if the vectors don't have all the same variables.
  if (s==first) {allres = result}
  else {
        allres=rbind.fill(allres,result)
        }
   } # s
  fn = paste(sumlab,".csv",sep="")
  write.csv(allres, fn, row.names=FALSE, na=".")
 return(allres)
}
sumres=testsnps("compsnps1to2396.csv",1,2,0.95)

for(s in 1:23){
  first = 100*(s-1)+1
  last= 100*s
  
  cat("first=",first," last=",last,"\n")
  sumres=testsnps("compsnps1to2396.csv",first,last,0.95)
}

sumres=testsnps("compsnps1to2396.csv",2301,2396,0.95)
# sumres1=testsnps(min(snpdata[,"focalnum"]),min(snpdata[,"focalnum"]),1)
# 
# snp = subset(snpdata,focalnum==1)
# # omits all the columns with missing SNP data.
# 
# snp=snp[,colSums(is.na(snp))==0]
# snpcols=ncol(snp)
# thissnp=merge(snp,lsmean184,by="DGRP")
# pcols=c(6:snpcols,(snpcols+65):(snpcols+77))
# pdf = data.matrix(thissnp[,pcols])
# rdf = data.matrix(thissnp[,(snpcols+5):(snpcols+63)])
# cvnlda = cv.glmnet(pdf,rdf,family="mgaussian",alpha=1)
# # plot(cvnlda)
# # find the lambda value that minimizes the cross-validated error
# bestlamb=cvnlda$lambda[which.min(cvnlda$cvm)]
# 
# bestmodels =glmnet(pdf,rdf,family="mgaussian",alpha=1)
# deviance(bestmodels)
# bestmodels$dev.ratio[which(bestmodels$lambda==bestlamb)]
# which(bestmodels$lambda==bestlamb)
# bestmodels$lambda
# plot(bestmodels)
# sumlab=paste("summary","to",sep="")
# bmod =extractSNPs(bestmodels,1,bestlamb,sumlab)
# 
# bmod$bestmodel
# bmod$SNPdata
# 
# 
# snp = subset(snpdata,focalnum==1)
# # omits all the columns with missing SNP data.
# snp=snp[,colSums(is.na(snp))==0]
# snp[1,1]
# 
